#!/usr/bin/env python3

from pequod_agent.cluster.controllers import Controller, BootstrapController, ClusterController
from pequod_agent.cluster.manager import CoreManager, BootstrapCore, ClusterCore
from pequod_agent.cluster.lbupdater import LBUpdater, BootstrapLBUpdater, ClusterLBUpdater
from pequod_agent.cluster.registries import Registry, BootstrapRegistry, ClusterRegistry
from pequod_agent.utilities.metaclasses import Singleton


class Cluster(metaclass=Singleton):
    def __init__(self,
                 pequod_controller: Controller,
                 core_manager: CoreManager,
                 lb_updater: LBUpdater,
                 registry: Registry,
                 credentials: dict):
        self.controller = pequod_controller
        self.core_manager = core_manager
        self.lb_updater = lb_updater
        self.registry = registry
        self.credentials = credentials

    @classmethod
    def setup_bootstrap(cls, hostname, bootstrap_identifiers):
        core_manager = BootstrapCore(bootstrap_identifiers)
        controller = BootstrapController(hostname, bootstrap_identifiers)
        lb_updater = BootstrapLBUpdater(bootstrap_identifiers)
        registry = BootstrapRegistry(bootstrap_identifiers)
        return cls(controller, core_manager, lb_updater, registry, None)

    @classmethod
    def setup_core_seeds(cls, hostname, core_seeds):
        # use initial IP-based authentication to retrieve agent credentials
        temp_manager = ClusterCore(core_seeds, None)
        credentials = temp_manager.get_credentials(hostname)
        controller = ClusterController(hostname, core_seeds, credentials)
        core_manager = ClusterCore(core_seeds, credentials)
        registry = ClusterRegistry(core_seeds, credentials)
        lb_updater = ClusterLBUpdater(controller, registry, credentials)
        return cls(controller, core_manager, lb_updater, registry, credentials)