#!/usr/bin/env python3

import resource
from pequod_agent.constants.resources import DEFAULT_CPU_VMHZ, DEFAULT_PROCESSES_COUNT, DEFAULT_FILEHANDLES_COUNT
from pequod_agent.utilities.sysinfo import cpu_total_mhz, cpu_count


def setup_cgroups(cid: str, resources: dict):
    with open('/sys/fs/cgroup/cpu/docker/{}/cpu.cfs_period_us'.format(cid)) as fd:
        cfs_period_us = int(fd.read())

    system_vmhz = cpu_total_mhz()
    container_vmhz = resources.get('cpu_vmhz', DEFAULT_CPU_VMHZ)
    cpus = cpu_count()
    quota = int(round(container_vmhz / system_vmhz * cpus * cfs_period_us))

    with open('/sys/fs/cgroup/cpu/docker/{}/cpu.cfs_quota_us'.format(cid), 'w') as fd:
        fd.write(str(quota))


def setup_container_rlimits(pid: str, resources: dict):
    nproc = resources.get('processes_count', DEFAULT_PROCESSES_COUNT)
    nofile = resources.get('filehandles_count', DEFAULT_FILEHANDLES_COUNT)
    resource.prlimit(pid, resource.RLIMIT_NPROC, (nproc, nproc))
    resource.prlimit(pid, resource.RLIMIT_NOFILE, (nofile, nofile))