import logging
import shlex
import subprocess

log = logging.getLogger('pequod.iptables')


def _cmd(cmd, **kwargs):
    return ['ip6tables'] + [arg.format(**kwargs) for arg in shlex.split(cmd)]


def _ip6tables(cmd):
    log.debug(' '.join(cmd))
    try:
        subprocess.check_call(cmd)
    except subprocess.CalledProcessError as e:
        log.exception(e.output)
        raise


def ip6tables(cmd, **kwargs):
    cmd = _cmd(cmd, **kwargs)
    _ip6tables(cmd)


def ensure(rule, **kwargs):
    log.debug('Ensure \'%s\'', rule.format(**kwargs))
    rule = [arg.format(**kwargs) for arg in shlex.split(rule)]
    check_cmd = ['ip6tables', '-C'] + rule
    add_cmd = ['ip6tables', '-A'] + rule
    code = subprocess.call(check_cmd, stderr=subprocess.DEVNULL)
    if code != 0:
        _ip6tables(add_cmd)
    return code != 0