#!/usr/bin/env python3
import logging
import random


log = logging.getLogger('pequod.agent.utils')


def generate_random_name(prefix: str, size: int) -> str:
    """
    See GenerateRandomName in vendor/src/github.com/docker/libcontainer/utils/utils.go

    >>> len(generate_random_name('abc', 4))
    7
    """
    return '{}%0{}x'.format(prefix, size) % random.randrange(16 ** size)


def pretty_print(d: dict) -> str:
    """
    >>> pretty_print({'a': 1, 'b': 2})
    'a=1, b=2'
    """
    return ', '.join(['{}={}'.format(k, v) for k, v in sorted(d.items())])


def ordinal(number: int) -> str:
    """
    >>> ordinal(1)
    '1st'
    >>> ordinal(11)
    '11th'
    >>> ordinal(111)
    '111th'
    >>> ordinal(121)
    '121st'
    >>> ordinal(2)
    '2nd'
    >>> ordinal(12)
    '12th'
    >>> ordinal(112)
    '112th'
    >>> ordinal(122)
    '122nd'
    >>> ordinal(3)
    '3rd'
    >>> ordinal(13)
    '13th'
    >>> ordinal(113)
    '113th'
    >>> ordinal(123)
    '123rd'
    """
    string_representation = str(number)
    suffix = 'th'
    if string_representation.endswith('1') and not string_representation.endswith('11'):
        suffix = 'st'
    elif string_representation.endswith('2') and not string_representation.endswith('12'):
        suffix = 'nd'
    elif string_representation.endswith('3') and not string_representation.endswith('13'):
        suffix = 'rd'
    return '{number}{suffix}'.format(**locals())